@@ -8,7 +8,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjGanttChart.cpp 1497 2007-06-13 07:54:55Z cs $
+ * $Id$
  */
 
 #include "TjGanttChart.h"
@@ -45,6 +45,7 @@ TjGanttChart::TjGanttChart(QObject* obj)
 
     project = 0;
     objPosTable = 0;
+    selectedObject = 0;
 
     dpiX = dpiY = 0;
     headerMargin = 0;
@@ -54,7 +55,7 @@ TjGanttChart::TjGanttChart(QObject* obj)
     colors["headerLineCol"] = Qt::black;
     colors["headerShadowCol"] = Qt::white;
     colors["chartBackgroundCol"] = Qt::white;
-    colors["chartAltBackgroundCol"] = Qt::white;
+    colors["chartAltBackgroundCol"] = Qt::lightGray.light(125);
     colors["chartTimeOffCol"] = QColor("#CECECE");
     colors["chartLineCol"] = QColor("#4F4F4F");
     colors["todayLineCol"] = Qt::green;
@@ -68,6 +69,8 @@ TjGanttChart::TjGanttChart(QObject* obj)
     colors["taskLoadCol"] = QColor("#FD13C6");
     colors["otherLoadCol"] = QColor("#FF8D13");
     colors["freeLoadCol"] = QColor("#00AC00");
+    colors["loadFrameCol"] = Qt::black;
+    colors["hightlightCol"] = Qt::white;
 
     currentZoomStep = 0;
     clipped = false;
@@ -102,13 +105,24 @@ TjGanttChart::setSizes(const TjObjPosTable* opt, int hh, int ch, int w,
     minRowHeight = mrh;
 
     assert(headerHeight > 0);
-    assert(chartHeight > 0);
     assert(width > 0);
 
     header->resize(width, headerHeight);
     chart->resize(width, chartHeight);
 }
 
+void
+TjGanttChart::setSelection(const TjObjPosTableEntry* selObj)
+{
+    // Make sure that setProjectAndReportData() has been called first.
+    assert(project != 0);
+
+    // Make sure that we have an option position translation table.
+    assert(objPosTable != 0);
+
+    selectedObject = selObj;
+}
+
 void
 TjGanttChart::setDPI(int dx, int dy)
 {
@@ -314,12 +328,6 @@ TjGanttChart::calcLegendHeight(int width)
 void
 TjGanttChart::generate(ScaleMode scaleMode)
 {
-    // Make sure setSizes() has been called first();
-    assert(objPosTable != 0);
-    /* Make sure that setHeaderHeight() or calcHeaderHeight() have been called
-     * first. */
-    assert(headerMargin > 0);
-
     // Clear ganttHeader canvas.
     QCanvasItemList cis = header->allItems();
     for (QCanvasItemList::Iterator it = cis.begin(); it != cis.end(); ++it)
@@ -330,6 +338,12 @@ TjGanttChart::generate(ScaleMode scaleMode)
     for (QCanvasItemList::Iterator it = cis.begin(); it != cis.end(); ++it)
         delete *it;
 
+    // Make sure setSizes() has been called first();
+    assert(objPosTable != 0);
+    /* Make sure that setHeaderHeight() or calcHeaderHeight() have been called
+     * first. */
+    assert(headerMargin > 0);
+
     switch (scaleMode)
     {
         case autoZoom:
@@ -377,7 +391,6 @@ TjGanttChart::generate(ScaleMode scaleMode)
                 endTime = unclippedEndTime;
                 clipped = false;
             }
-
             break;
         }
         default:
@@ -408,7 +421,8 @@ TjGanttChart::generate(ScaleMode scaleMode)
 
     generateHeaderAndGrid();
 
-    generateGanttElements();
+    if (!objPosTable->isEmpty())
+        generateGanttElements();
 
     header->update();
     chart->update();
@@ -734,6 +748,11 @@ TjGanttChart::generateHeaderAndGrid()
 
     generateHeaderLine(0);
     generateHeaderLine(headerHeight / 2);
+
+    // For empty reports we only draw the header.
+    if (objPosTable->isEmpty())
+        return;
+
     TjGanttZoomStep* czs = zoomSteps[currentZoomStep];
     switch (czs->getStepUnit(false))
     {
@@ -776,7 +795,7 @@ TjGanttChart::generateHeaderAndGrid()
                 markQuarterBoundaries();
             break;
     }
-    //generateGanttBackground();
+    generateGanttBackground();
 
     // Draw a red line to mark the current time.
     if (reportDef->getProject()->getNow() >=
@@ -989,6 +1008,7 @@ TjGanttChart::markQuarterBoundaries()
 void
 TjGanttChart::generateGanttBackground()
 {
+    // Paint the whole chart with the background color.
     QCanvasRectangle* rect =
         new QCanvasRectangle(0, 0, chart->width(), chart->height(),
                              chart);
@@ -998,17 +1018,36 @@ TjGanttChart::generateGanttBackground()
     rect->setZ(TJRL_BACKGROUND);
     rect->show();
 
-    bool toggle = false;
-    for (int y = 0; y < chartHeight; y += 25) // Just temporary
-    {
-        toggle = !toggle;
-        if (toggle)
-            continue;
+    /* Now paint every other line with the alternative background color. This
+     * only works if the chart has the same height for all lines. If this is
+     * not the case the alterntive color should be identical to the background
+     * color. */
+    if (colors["chartBackgroundCol"] != colors["chartAltBackgroundCol"])
+        for (TjObjPosTableConstIterator it(*objPosTable); *it; ++it)
+        {
+            /* The isAlternate() method is the cleaner code, but does not work
+             * reliably as the alternate setting seems to lag the LVI
+             * positioning.
+            if (!(*it)->isAlternate())
+                continue;*/
+            if (((*it)->getPos() / (*it)->getHeight()) % 2 == 0)
+                continue;
+            rect = new QCanvasRectangle(0, (*it)->getPos(), width,
+                                        (*it)->getHeight(), chart);
+            rect->setPen(QPen(Qt::NoPen));
+            rect->setBrush(QBrush(colors["chartAltBackgroundCol"]));
+            rect->setZ(TJRL_BACKLINES);
+            rect->show();
+        }
 
-        rect = new QCanvasRectangle(0, y, width, 25, chart);
+    // Highlight the selected object
+    if (selectedObject)
+    {
+        rect = new QCanvasRectangle(0, selectedObject->getPos(),
+                                    width, selectedObject->getHeight(), chart);
         rect->setPen(QPen(Qt::NoPen));
-        rect->setBrush(QBrush(colors["chartAltBackgroundCol"]));
-        rect->setZ(TJRL_BACKLINES);
+        rect->setBrush(QBrush(colors["hightlightCol"], Qt::Dense4Pattern));
+        rect->setZ(TJRL_HIGHLIGHT);
         rect->show();
     }
 }
@@ -1044,15 +1083,14 @@ TjGanttChart::generateGanttElements()
                 ((*it)->getSubCoreAttributes());
             drawTaskResource(r, t);
         }
-        else if ((*it)->getCoreAttributes()->getType() ==
-                 CA_Resource &&
+        else if ((*it)->getCoreAttributes()->getType() == CA_Resource &&
                  (*it)->getSubCoreAttributes()->getType() == CA_Task)
         {
             Resource* r = static_cast<Resource*>
                 ((*it)->getCoreAttributes());
             const Task* t = static_cast<const Task*>
                 ((*it)->getSubCoreAttributes());
-            drawTask(t, r);
+            drawResourceTask(r, t);
         }
         else
             assert(0);
@@ -1060,6 +1098,37 @@ TjGanttChart::generateGanttElements()
     delete collisionDetector;
 }
 
+bool
+TjGanttChart::shouldTaskBeDrawnAsContainer(const Task* t)
+{
+  // a non-container task should not be drawn as a container
+  if (!t->isContainer())
+    return false;
+  // a container should allways be drawn as a container if
+  // 'drawemptycontainersastasks' is not set
+  if (!project->getDrawEmptyContainersAsTasks())
+    return true;
+  // otherwise, it should be drawn as a container if and only
+  // none of its subtasks are shown
+  for (TjObjPosTableConstIterator it(*objPosTable); *it; ++it)
+    {
+      const Task* t2;
+      if ((*it)->getCoreAttributes()->getType() == CA_Task)
+	t2 = static_cast<const Task*>
+	  ((*it)->getCoreAttributes());
+      else if ((*it)->getSubCoreAttributes() &&
+	       (*it)->getSubCoreAttributes()->getType() ==
+                 CA_Task)
+	t2 = static_cast<const Task*>
+	  ((*it)->getSubCoreAttributes());
+      else
+	continue;
+      if (t->isSubTask(t2))
+	return true;
+    }
+  return false;
+}
+
 void
 TjGanttChart::drawTask(const Task* t, const Resource* r)
 {
@@ -1082,7 +1151,7 @@ TjGanttChart::drawTask(const Task* t, const Resource* r)
         drawMilestoneShape(centerX, centerY, minRowHeight,
                            t->isOnCriticalPath(scenario), r != 0, chart);
     }
-    else if (t->isContainer())
+    else if (shouldTaskBeDrawnAsContainer(t))
     {
         int start = time2x(t->getStart(scenario));
         int end = time2x(t->getEnd(scenario));
@@ -1109,8 +1178,9 @@ TjGanttChart::drawTask(const Task* t, const Resource* r)
             barWidth = (int) ((end - start) *
                               (t->getCompletionDegree(scenario) / 100.0));
 
+	bool critical = t->isOrHasDescendantOnCriticalPath(scenario);
         drawTaskShape(start, end, centerY, minRowHeight, barWidth,
-                      t->isOnCriticalPath(scenario, true), r != 0, chart);
+                      critical, r != 0, chart);
     }
 }
 
@@ -1122,7 +1192,12 @@ TjGanttChart::drawTaskShape(int start, int end, int centerY, int height,
     /* Workaround for a QCanvasView problem. In Qt3.x it can only handle 32767
      * pixels per dimension. */
     if (start < 0)
+    {
+        barWidth += start;
+        if (barWidth < 0)
+            barWidth = 0;
         start = 0;
+    }
     else if (start > 32767)
         start = 32767;
     if (end < 0)
@@ -1148,6 +1223,9 @@ TjGanttChart::drawTaskShape(int start, int end, int centerY, int height,
     // The black progress bar.
     if (barWidth > 0)
     {
+        if (barWidth > (end - start))
+            qDebug("Bar too wide!");
+
         rect = new QCanvasRectangle
             (start, centerY - (int) (height * 0.12), barWidth,
              (int) (height * 0.24) + 1, canvas);
@@ -1488,6 +1566,26 @@ TjGanttChart::drawTaskResource(Resource* r, const Task* t)
                               rY);
 }
 
+void
+TjGanttChart::drawResourceTask(Resource* r, const Task* t)
+{
+    assert(zoomSteps.size() > 0);
+
+    if (t->getStart(scenario) == 0 || t->getEnd(scenario) == 0)
+        return;
+
+    /* For each time interval we draw a column that represents the load of the
+     * resource allocated to the task. The load bar height is normalized on
+     * the total allocatable load of the task for that time slot. */
+    Interval iv;
+    TjGanttZoomStep* czs = zoomSteps[currentZoomStep];
+    int rY = objPosTable->caToPos(r, t);
+    for (time_t i = czs->intervalStart(false, t->getStart(scenario));
+         i <= (t->getEnd(scenario)); i = czs->nextIntervalStart(false, i))
+        drawResourceLoadColum(r, t, i, czs->nextIntervalStart(false, i) - 1,
+                              rY, true);
+}
+
 void
 TjGanttChart::drawResource(Resource* r)
 {
@@ -1506,7 +1604,8 @@ TjGanttChart::drawResource(Resource* r)
 
 void
 TjGanttChart::drawResourceLoadColum(Resource* r, const Task* t,
-                                    time_t start, time_t end, int rY)
+                                    time_t start, time_t end, int rY,
+                                    bool taskLoadOnly)
 {
     if (t && (t->getStart(scenario) == 0 || t->getEnd(scenario) == 0))
         return;
@@ -1546,7 +1645,7 @@ TjGanttChart::drawResourceLoadColum(Resource* r, const Task* t,
     if (cx + cw > cellEnd - mmToXPixels(0.6))
         cw = cellEnd - mmToXPixels(0.6) - cx;
 
-    // Now we are calculation the load of the resource with respect to this
+    // Now we are calculating the load of the resource with respect to this
     // task, to all tasks, and we calculate the not yet allocated load.
     Interval period(start, end);
     double freeLoad = r->getEffectiveFreeLoad(scenario, period);
@@ -1589,6 +1688,12 @@ TjGanttChart::drawResourceLoadColum(Resource* r, const Task* t,
                     "taskLoadCol", pattern1, chart);
     }
 
+    if (taskLoadOnly)
+    {
+        drawLoadFrame(cx, colTop, cw, colBottom - colTop, chart);
+        return;
+    }
+
     if (otherLoad > 0.0)
     {
         // Load for other tasks.
@@ -1616,6 +1721,17 @@ TjGanttChart::drawLoadBar(int cx, int cy, int cw, int ch, const QString& col,
     rect->show();
 }
 
+void
+TjGanttChart::drawLoadFrame(int cx, int cy, int cw, int ch, QCanvas* canvas)
+{
+    QCanvasRectangle* rect = new QCanvasRectangle
+        (cx, cy, cw, ch, canvas);
+    rect->setBrush(QBrush(Qt::NoBrush));
+    rect->setPen(QPen(colors["loadFrameCol"], lineWidth));
+    rect->setZ(TJRL_LOADBARFRAMES);
+    rect->show();
+}
+
 QStringList
 TjGanttChart::getZoomStepLabels() const
 {
