@@ -8,7 +8,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjGanttChart.h 1428 2007-03-17 15:24:21Z cs $
+ * $Id$
  */
 #ifndef _TjGanttChart_h_
 #define _TjGanttChart_h_
@@ -37,6 +37,7 @@ class TjObjPosTable;
 class TjGanttZoomStep;
 class Interval;
 class TjLineAccounter;
+class TjObjPosTableEntry;
 
 class TjGanttChart
 {
@@ -49,6 +50,7 @@ public:
     void setProjectAndReportData(const QtReportElement* r);
     void setSizes(const TjObjPosTable* opt, int headerHeight, int chartHeight,
                   int width, int minRowHeight);
+    void setSelection(const TjObjPosTableEntry* selObj);
     void setDPI(int dx, int dy);
 
     void setColor(const char* name, QColor col);
@@ -100,6 +102,7 @@ private:
     void markQuarterBoundaries();
 
     void generateGanttElements();
+    bool shouldTaskBeDrawnAsContainer(const Task* t);
     void drawTask(const Task* t, const Resource* r);
     void drawTaskShape(int start, int end, int centerY, int height,
                        int barWidth, bool critical, bool outlineOnly,
@@ -111,12 +114,14 @@ private:
     void drawDependencies(const Task* t1, TjLineAccounter* collisionDetector);
     void drawTaskResource(Resource* r, const Task* t);
     void drawResource(Resource* r);
-    void drawResourceTask(const Task* t, Resource* r);
+    void drawResourceTask(Resource* r, const Task* t);
+    void drawTaskResource(const Task* t, Resource* r);
     void drawResourceLoadColum(Resource* r, const Task* t, time_t start,
-                               time_t end, int rY);
+                               time_t end, int rY, bool taskLoadOnly = false);
 
     void drawLoadBar(int cx, int cy, int cw, int ch, const QString& col,
                      Qt::BrushStyle pattern, QCanvas* canvas);
+    void drawLoadFrame(int cx, int cy, int cw, int ch, QCanvas* canvas);
     void zoomToFitWindow(int width, time_t duration);
     void allTasksInterval();
 
@@ -144,6 +149,8 @@ private:
 
     const TjObjPosTable* objPosTable;
 
+    const TjObjPosTableEntry* selectedObject;
+
     int headerMargin;
     int headerHeight;
     int chartHeight;
