@@ -1,13 +1,14 @@
 /*
  * The TaskJuggler Project Management Software
  *
- * Copyright (c) 2001, 2002, 2003, 2004, 2005 by Chris Schlaeger <cs@kde.org>
+ * Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007
+ * by Chris Schlaeger <cs@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjReport.cpp 1497 2007-06-13 07:54:55Z cs $
+ * $Id$
  */
 
 #include "TjReport.h"
@@ -34,6 +35,7 @@
 #include <ktextbrowser.h>
 #include <krun.h>
 #include <kmessagebox.h>
+#include <klistviewsearchline.h>
 
 #include "Project.h"
 #include "Task.h"
@@ -53,16 +55,22 @@
 #include "KPrinterWrapper.h"
 #include "UsageLimits.h"
 #include "ReportManager.h"
+#include "ReportController.h"
+#include "kdateedit.h"
 
-TjReport::TjReport(QWidget* p, ReportManager* m, Report* const rDef,
+TjReport::TjReport(QWidget* p, ReportManager* m, Report* rDef,
                    const QString& n)
     : TjUIReportBase(p, m, rDef, n)
 {
     loadingProject = false;
-    autoFit = true;
+    scaleMode = TjGanttChart::fitSize;
 
-    QHBoxLayout* hl = new QHBoxLayout(this, 0, 0);
-    splitter = new QSplitter(Horizontal, this);
+    QVBoxLayout* vl = new QVBoxLayout(this, 0, 0);
+    reportFrame = new QWidget(this);
+    reportFrame->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+
+    QHBoxLayout* hl = new QHBoxLayout(reportFrame, 0, 0);
+    splitter = new QSplitter(Horizontal, reportFrame);
 
     listView = new KListView(splitter);
     listView->setRootIsDecorated(true);
@@ -73,10 +81,10 @@ TjReport::TjReport(QWidget* p, ReportManager* m, Report* const rDef,
     listView->setItemMargin(2);
 
     canvasFrame = new QWidget(splitter);
-    QVBoxLayout* vl = new QVBoxLayout(canvasFrame, 0, 0);
+    QVBoxLayout* vlChart = new QVBoxLayout(canvasFrame, 0, 0);
     canvasFrame->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Preferred);
 
-    ganttChart = new TjGanttChart(this);
+    ganttChart = new TjGanttChart(reportFrame);
     objPosTable = 0;
 
     ganttHeaderView = new QCanvasView(ganttChart->getHeaderCanvas(),
@@ -88,14 +96,21 @@ TjReport::TjReport(QWidget* p, ReportManager* m, Report* const rDef,
                                      canvasFrame);
     ganttChartView->setVScrollBarMode(QScrollView::AlwaysOff);
 
-    startTime = endTime = 0;
+    reportController = new ReportController(this);
+    reportController->reportSearch->setListView(listView);
+    reportController->reportStart->setDate(time2qdate(rDef->getStart()));
+    reportController->reportEnd->setDate(time2qdate(rDef->getEnd()));
 
-    vl->addWidget(ganttHeaderView);
-    vl->addWidget(ganttChartView);
+    vl->addWidget(reportFrame);
+    vl->addWidget(reportController);
+    vlChart->addWidget(ganttHeaderView);
+    vlChart->addWidget(ganttChartView);
     hl->addWidget(splitter);
 
     statusBarUpdateTimer = delayTimer = 0;
 
+    connect(listView, SIGNAL(selectionChanged()),
+            this, SLOT(regenerateChart()));
     connect(listView, SIGNAL(expanded(QListViewItem*)),
             this, SLOT(expandReportItem(QListViewItem*)));
     connect(listView, SIGNAL(collapsed(QListViewItem*)),
@@ -111,6 +126,12 @@ TjReport::TjReport(QWidget* p, ReportManager* m, Report* const rDef,
             this, SLOT(syncVSlidersGantt2List(int, int)));
     connect(listView, SIGNAL(contentsMoving(int, int)),
             this, SLOT(syncVSlidersList2Gantt(int, int)));
+    connect(reportController->reportSearch, SIGNAL(textChanged(const QString&)),
+            this, SLOT(reportSearchTriggered(const QString&)));
+    connect(reportController->reportStart, SIGNAL(dateChanged(const QDate&)),
+            this, SLOT(setReportStart(const QDate&)));
+    connect(reportController->reportEnd, SIGNAL(dateChanged(const QDate&)),
+            this, SLOT(setReportEnd(const QDate&)));
 
     indexColumns.insert("index");
     indexColumns.insert("hierarchindex");
@@ -180,6 +201,12 @@ done:
     delete printer;
 }
 
+void
+TjReport::setFocus()
+{
+    listView->setFocus();
+}
+
 bool
 TjReport::event(QEvent* ev)
 {
@@ -189,6 +216,8 @@ TjReport::event(QEvent* ev)
         setGanttChartColors();
         regenerateChart();
     }
+    else if (ev->type() == QEvent::MouseButtonPress)
+        handleMouseEvent(static_cast<QMouseEvent*>(ev));
 
     return QWidget::event(ev);
 }
@@ -212,10 +241,7 @@ TjReport::generateReport()
      * layouted yet. So we can't set the splitter to a good size and generate
      * the gantt report immediately. We use a 200ms timer to delay the
      * rendering. Hopefully by then the window has been layouted properly. */
-    delayTimer = new QTimer(this);
-    connect(delayTimer, SIGNAL(timeout()),
-            this, SLOT(regenerateChart()));
-    delayTimer->start(200, true);
+    triggerChartRegeneration(200);
 
     delete statusBarUpdateTimer;
     statusBarUpdateTimer = new QTimer(this);
@@ -226,6 +252,18 @@ TjReport::generateReport()
     return true;
 }
 
+void
+TjReport::triggerChartRegeneration(int msDelay)
+{
+    if (delayTimer == 0)
+    {
+        delayTimer = new QTimer(this);
+        connect(delayTimer, SIGNAL(timeout()),
+                this, SLOT(regenerateChart()));
+    }
+    delayTimer->start(msDelay, true);
+}
+
 void
 TjReport::regenerateChart()
 {
@@ -237,8 +275,8 @@ TjReport::regenerateChart()
     prepareChart();
 
     // When we are here, we have rendered the widgets at least once. So we can
-    // turn off autoFit mode.
-    autoFit = false;
+    // turn off manual mode.
+    scaleMode = TjGanttChart::manual;
 
     ganttChart->getHeaderCanvas()->update();
     ganttChart->getChartCanvas()->update();
@@ -248,7 +286,7 @@ TjReport::regenerateChart()
 
 void
 TjReport::generateTaskListLine(const QtReportElement* reportElement,
-                               const Task* t, QListViewItem* lvi,
+                               const Task* t, KListViewItem* lvi,
                                const Resource* r)
 {
     assert(reportElement != 0);
@@ -312,6 +350,30 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
                 }
             }
         }
+        else if ((*ci)->getName() == "completedeffort")
+        {
+            double val = 0.0;
+            if (!r && t->isLeaf())
+            {
+                // Task line, no resource.
+                val = t->getCompletedLoad(scenario);
+            }
+            else if (t && t->isLeaf())
+            {
+                // Task line, nested into a resource
+                const Project* project = report->getProject();
+                time_t now = project->getNow();
+                if (now < project->getStart())
+                    now = project->getStart();
+                if (now > project->getEnd())
+                    now = project->getEnd();
+                Interval iv = Interval(project->getStart(), now);
+                val = t->getLoad(scenario, iv, r);
+            }
+            cellText = indent
+                (reportElement->scaledLoad(val, tcf->realFormat),
+                 lvi, tcf->getHAlign() == TableColumnFormat::right);
+        }
         else if ((*ci)->getName() == "cost")
         {
             double val = t->getCredits
@@ -413,6 +475,30 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
                               lvi, tcf->getHAlign() ==
                               TableColumnFormat::right);
         }
+        else if ((*ci)->getName() == "remainingeffort")
+        {
+            double val = 0.0;
+            if (!r && t->isLeaf())
+            {
+                // Task line, no resource.
+                val = t->getRemainingLoad(scenario);
+            }
+            else if (t && t->isLeaf())
+            {
+                // Task line, nested into a resource
+                const Project* project = report->getProject();
+                time_t now = project->getNow();
+                if (now < project->getStart())
+                    now = project->getStart();
+                if (now > project->getEnd())
+                    now = project->getEnd();
+                Interval iv = Interval(now, project->getEnd());
+                val = t->getLoad(scenario, iv, r);
+            }
+            cellText = indent
+                (reportElement->scaledLoad(val, tcf->realFormat),
+                 lvi, tcf->getHAlign() == TableColumnFormat::right);
+        }
         else if ((*ci)->getName() == "resources")
         {
             for (ResourceListIterator rli
@@ -438,6 +524,8 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
                               lvi, tcf->getHAlign() ==
                               TableColumnFormat::right);
         }
+        else if ((*ci)->getName() == "scheduling")
+            cellText = t->getSchedulingText();
         else if ((*ci)->getName() == "start")
             cellText = time2user(t->getStart(scenario),
                                  reportElement->getTimeFormat());
@@ -470,7 +558,7 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
 
 void
 TjReport::generateResourceListLine(const QtReportElement* reportElement,
-                                   Resource* r, QListViewItem* lvi,
+                                   Resource* r, KListViewItem* lvi,
                                    const Task* t)
 {
     assert(reportElement != 0);
@@ -664,11 +752,13 @@ TjReport::prepareChart()
      * re-generation. So we delete it and create a new one. */
     delete objPosTable;
     objPosTable = new TjObjPosTable;
-    for (std::map<const QString, QListViewItem*, ltQString>::iterator
+    TjObjPosTableEntry* selectedObject = 0;
+
+    for (std::map<const QString, KListViewItem*, ltQString>::iterator
          lvit = ca2lviDict.begin(); lvit != ca2lviDict.end(); ++lvit)
     {
-        const QListViewItem* lvi = (*lvit).second;
-        if (!lvi)
+        KListViewItem* lvi = (*lvit).second;
+        if (!lvi || !lvi->isVisible())
             continue;
 
         // Find out if the list entry is visible at all.
@@ -712,42 +802,35 @@ TjReport::prepareChart()
             }
         }
         assert(ca1 != 0);
-        objPosTable->addEntry(ca1, ca2, lvi->itemPos(), lvi->height());
-    }
+        TjObjPosTableEntry* tableEntry =
+            objPosTable->addEntry(ca1, ca2, lvi->itemPos(), lvi->height(),
+                                  lvi->isAlternate());
 
-    // Make sure that we only prepare the chart if the listView isn't empty.
-
-    if (!listView->firstChild())
-    {
-        QValueList<int> sizes;
-        sizes.append(width());
-        sizes.append(0);
-        splitter->setSizes(sizes);
-        KMessageBox::information
-            (this, i18n("The report does not contain any data. Either there "
-                        "were no properties defined for this report or the "
-                        "filter expressions have eliminated all entries."),
-             QString::null, "EmptyReportInfo");
-        return;
+        if (lvi == listView->selectedItem())
+            selectedObject = tableEntry;
     }
 
     // Calculate some commenly used values;
     headerHeight = listView->header()->height();
-    itemHeight = listView->firstChild()->height();
     QListViewItem* lvi;
-    for (lvi = listView->firstChild(); lvi && lvi->itemBelow();
-         lvi = lvi->itemBelow())
-        ;
-    listHeight = lvi->itemPos() + itemHeight;
+    itemHeight = 0;
+    listHeight = 0;
+    for (lvi = listView->firstChild(); lvi; lvi = lvi->itemBelow())
+        if (lvi->isVisible())
+        {
+            if (lvi->height() > itemHeight)
+                itemHeight = lvi->height();
+            listHeight = lvi->itemPos() + itemHeight - 1;
+        }
 
     // Resize header canvas to new size.
     ganttHeaderView->setFixedHeight(headerHeight);
 
     ganttChart->setProjectAndReportData(getReportElement());
     QValueList<int> sizes = splitter->sizes();
-    if (autoFit)
+    if (scaleMode == TjGanttChart::fitSize)
     {
-        /* In autoFit mode we show 1/3 table and 2/3 gantt chart. Otherwise we
+        /* In fitSize mode we show 1/3 table and 2/3 gantt chart. Otherwise we
          * just keep the current size of the splitter. */
         if (showGantt)
         {
@@ -766,12 +849,12 @@ TjReport::prepareChart()
                          sizes[1] == 0 ? static_cast<int>(width() * 2.0/3.0) :
                          sizes[1],
                          itemHeight);
+    ganttChart->setSelection(selectedObject);
     QPaintDeviceMetrics metrics(ganttChartView);
     ganttChart->setDPI(metrics.logicalDpiX(), metrics.logicalDpiY());
     setGanttChartColors();
     ganttChart->setHeaderHeight(headerHeight);
-    ganttChart->generate(autoFit ? TjGanttChart::fitSize:
-                         TjGanttChart::manual);
+    ganttChart->generate(scaleMode);
     updateZoomSelector();
 
     canvasFrame->setMaximumWidth(ganttChart->getWidth());
@@ -1114,8 +1197,9 @@ TjReport::showResourceDetails(Resource* resource)
     richTextDisplay->textDisplay->setTextFormat(Qt::RichText);
 
     QString text;
-    Interval iv = Interval(report->getStart(),
-                           report->getEnd());
+    const ReportElement* reportElement = this->getReportElement();
+    Interval iv = Interval(reportElement->getStart(),
+                           reportElement->getEnd());
     double load = resource->getEffectiveLoad(scenario, iv);
     double freeLoad = resource->getEffectiveFreeLoad(scenario, iv);
 
@@ -1217,22 +1301,25 @@ TjReport::syncVSlidersList2Gantt(int, int y)
     }
 }
 
+void
+TjReport::handleMouseEvent(const QMouseEvent* ev)
+{
+    QPoint pos;
+    QListViewItem* lvi = getChartItemBelowCursor(pos);
+    if (!lvi)
+        return;
+
+    if (ev->button() == Qt::LeftButton)
+        listView->setSelected(lvi, true);
+    else if (ev->button() == Qt::RightButton)
+        doPopupMenu(lvi, QCursor::pos(), 0);
+}
+
 void
 TjReport::updateStatusBar()
 {
-    if (loadingProject || !isVisible() || !ganttChartView->isVisible())
-        return;
-
-    QPoint pos = ganttChartView->mapFromGlobal(QCursor::pos());
-    if (pos.x() < 0 || pos.y() < 0 ||
-        pos.x() > ganttChartView->width() ||
-        pos.y() > ganttChartView->height())
-    {
-        emit signalChangeStatusBar("");
-        return;
-    }
-
-    QListViewItem* lvi = listView->itemAt(QPoint(50, pos.y()));
+    QPoint pos;
+    QListViewItem* lvi = getChartItemBelowCursor(pos);
     if (!lvi)
     {
         emit signalChangeStatusBar("");
@@ -1245,6 +1332,91 @@ TjReport::updateStatusBar()
     emit signalChangeStatusBar(this->generateStatusBarText(pos, ca, parent));
 }
 
+void
+TjReport::reportSearchTriggered(const QString&)
+{
+    triggerChartRegeneration(200);
+}
+
+void
+TjReport::setReportStart(const QDate& d)
+{
+    ReportElement* reportElement = this->getReportElement();
+    time_t start = qdate2time(d);
+
+    bool clipped = false;
+    if (start < date2time("2000-01-01"))
+    {
+        start = date2time("2000-01-01");
+        clipped = true;
+    }
+    if (start > date2time("2030-01-01"))
+    {
+        start = date2time("2030-01-01");
+        clipped = true;
+    }
+    if (start + (24 * 60 * 60) > reportElement->getEnd())
+    {
+        start = reportElement->getEnd() - (24 * 60 * 60);
+        clipped = true;
+    }
+    if (clipped)
+        reportController->reportStart->setDate(time2qdate(start));
+
+    reportElement->setStart(start);
+    scaleMode = TjGanttChart::autoZoom;
+    generateReport();
+}
+
+void
+TjReport::setReportEnd(const QDate& d)
+{
+    ReportElement* reportElement = this->getReportElement();
+    time_t end = qdate2time(d);
+
+    bool clipped = false;
+    if (end < date2time("2000-01-01"))
+    {
+        end = date2time("2000-01-01");
+        clipped = true;
+    }
+    if (end > date2time("2030-01-01"))
+    {
+        end = date2time("2030-01-01");
+        clipped = true;
+    }
+    if (end - (24 * 60 * 60) < reportElement->getStart())
+    {
+        end = reportElement->getStart() + (24 * 60 * 60);
+        clipped = true;
+    }
+    if (clipped)
+        reportController->reportEnd->setDate(time2qdate(end));
+
+    reportElement->setEnd(end);
+    scaleMode = TjGanttChart::autoZoom;
+    generateReport();
+}
+
+QListViewItem*
+TjReport::getChartItemBelowCursor(QPoint& pos)
+{
+    if (loadingProject || !isVisible() || !ganttChartView->isVisible())
+        return 0;
+
+    /* Since it is easier to map the global cursor position to the
+     * ganttChartView coordinates than using the event position we'll got for
+     * the easy way. */
+    pos = ganttChartView->mapFromGlobal(QCursor::pos());
+    // Make sure the cursor is really above the ganttChartView.
+    if (pos.x() < 0 || pos.y() < 0 ||
+        pos.x() > ganttChartView->width() ||
+        pos.y() > ganttChartView->height())
+        return 0;
+
+    return listView->itemAt(QPoint(50, pos.y()));
+}
+
 void
 TjReport::zoomTo(const QString& label)
 {
@@ -1388,14 +1560,12 @@ TjReport::setGanttChartColors()
     ganttChart->setColor("headerShadowCol", colorGroup().mid());
     ganttChart->setColor("chartBackgroundCol", listView->colorGroup().base());
     ganttChart->setColor("chartAltBackgroundCol",
-                         KGlobalSettings::calculateAlternateBackgroundColor
-                         (listView->colorGroup().base()));
+                         listView->alternateBackground());
     ganttChart->setColor("chartTimeOffCol",
-                         KGlobalSettings::calculateAlternateBackgroundColor
-                         (listView->colorGroup().base()).dark(110));
+                         listView->alternateBackground().dark(110));
     ganttChart->setColor("chartLineCol",
-                         KGlobalSettings::calculateAlternateBackgroundColor
-                         (listView->colorGroup().base()).dark(130));
+                         listView->alternateBackground().dark(130));
+    ganttChart->setColor("hightlightCol", colorGroup().highlight());
 }
 
 void
