@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjReportRow.h 1428 2007-03-17 15:24:21Z cs $
+ * $Id$
  */
 
 #ifndef _TjReportRow_h_
@@ -37,6 +37,9 @@ public:
     void setLastOnPage(bool lop) { lastOnPage = lop; }
     bool getLastOnPage() const { return lastOnPage; }
 
+    void setAlternate(bool alt) { alternate = alt; }
+    bool isAlternate() const { return alternate; }
+
     void insertCell(TjReportCell* c, int pos);
     TjReportCell* getCell(int pos) const;
 
@@ -60,6 +63,7 @@ private:
     bool hidden;
     // True if this row is the last row on the page.
     bool lastOnPage;
+    bool alternate;
     TjReportCell** cells;
 
     int index;
