@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjTaskReport.h 1315 2006-08-11 21:05:41Z cs $
+ * $Id$
  */
 
 #ifndef _TjTaskReport_h_
@@ -29,7 +29,7 @@ public:
                  const QString& n = QString::null);
     virtual ~TjTaskReport();
 
-    virtual const QtReportElement* getReportElement() const;
+    virtual QtReportElement* getReportElement() const;
 
     virtual TjPrintReport* newPrintReport(KPrinter* pr);
 
