@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: CSVReportElement.cpp 1497 2007-06-13 07:54:55Z cs $
+ * $Id$
  */
 
 #include "CSVReportElement.h"
@@ -476,6 +476,13 @@ CSVReportElement::genCellHierarchIndex(TableCellInfo* tci)
             tci->tli->ca1->getHierarchIndex() : QString::null, tci, true);
 }
 
+void
+CSVReportElement::genCellHierarchLevel(TableCellInfo* tci)
+{
+    genCell(tci->tli->ca2 == 0 ?
+            tci->tli->ca1->getHierarchLevel() : QString::null, tci, true);
+}
+
 void
 CSVReportElement::genCellId(TableCellInfo* tci)
 {
@@ -845,6 +852,16 @@ CSVReportElement::genCellCompleted(TableCellInfo* tci)
     }
 }
 
+void
+CSVReportElement::genCellCompletedEffort(TableCellInfo*)
+{
+}
+
+void
+CSVReportElement::genCellRemainingEffort(TableCellInfo*)
+{
+}
+
 void
 CSVReportElement::genCellStatus(TableCellInfo* tci)
 {
@@ -1205,6 +1222,11 @@ CSVReportElement::genCellSchedule(TableCellInfo*)
 {
 }
 
+void
+CSVReportElement::genCellScheduling(TableCellInfo*)
+{
+}
+
 #define GCEFFORT(a) \
 void \
 CSVReportElement::genCell##a##Effort(TableCellInfo* tci) \
