@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ExportReport.h 1428 2007-03-17 15:24:21Z cs $
+ * $Id$
  */
 #ifndef _ExportReport_h_
 #define _ExportReport_h_
@@ -59,8 +59,8 @@ private:
     bool generateTaskAttributeList(TaskList& ftl);
     bool generateTaskSupplement(TaskList& ftl, const Task* task, int indent);
     bool generateDepList(TaskList& filteredTaskList, const Task* task,
-                         QPtrListIterator<TaskDependency> depIt,
-                         const char* tag, int indent);
+                         QPtrListIterator<TaskDependency> depIt, bool prev,
+                         int indent);
     bool generateResourceAttributesList(TaskList& ftl, ResourceList& frl);
     bool generateCustomAttributeValue(const QString& id,
                                       const CoreAttributes* property,
