@@ -8,7 +8,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ExpressionFunctionTable.cpp 1428 2007-03-17 15:24:21Z cs $
+ * $Id$
  */
 
 #include "ExpressionFunctionTable.h"
@@ -22,7 +22,7 @@ ExpressionFunctionTable::ExpressionFunctionTable() :
 {
     functions.setAutoDelete(true);
 
-    addFunc(KW("hasAssignments"), &ExpressionTreeFunction::hasAssignments, 2);
+    addFunc(KW("hasAssignments"), &ExpressionTreeFunction::hasAssignments, 3);
     addFunc(KW("isTask"), &ExpressionTreeFunction::isTask, 1);
     addFunc(KW("isATask"), &ExpressionTreeFunction::isATask, 0);
     addFunc(KW("isMilestone"), &ExpressionTreeFunction::isMilestone, 0);
@@ -37,7 +37,7 @@ ExpressionFunctionTable::ExpressionFunctionTable() :
     addFunc(KW("endsBefore"), &ExpressionTreeFunction::endsBefore, 2);
     addFunc(KW("endsAfter"), &ExpressionTreeFunction::endsAfter, 2);
     addFunc(KW("isParentOf"), &ExpressionTreeFunction::isParentOf, 1);
-    addFunc(KW("isChildOf"), &ExpressionTreeFunction::isChildOf, 1);
+    addFunc(KW("isChildOf"), &ExpressionTreeFunction::isDescendantOf, 1);
     addFunc(KW("isLeaf"), &ExpressionTreeFunction::isLeaf, 0);
     addFunc(KW("treeLevel"), &ExpressionTreeFunction::treeLevel, 0);
     addFunc(KW("isAllocated"), &ExpressionTreeFunction::isAllocated, 3);
