@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ExpressionTreeFunction.h 1406 2007-02-17 09:39:08Z cs $
+ * $Id$
  */
 #ifndef _ExpressionTreeFunction_h_
 #define _ExpressionTreeFunction_h_
@@ -50,7 +50,7 @@ public:
 
     long hasAssignments(ExpressionTree* et, Operation* const ops[]) const;
     long isParentOf(ExpressionTree* et, Operation* const ops[]) const;
-    long isChildOf(ExpressionTree* et, Operation* const ops[]) const;
+    long isDescendantOf(ExpressionTree* et, Operation* const ops[]) const;
     long isLeaf(ExpressionTree* et, Operation* const ops[]) const;
     long treeLevel(ExpressionTree* et, Operation* const ops[]) const;
     long isAccount(ExpressionTree* et, Operation* const ops[]) const;
