@@ -13,26 +13,24 @@
 #ifndef _HTMLMonthlyCalendar_h_
 #define _HTMLMonthlyCalendar_h_
 
-#include "HTMLReport.h"
+#include "HTMLSingleReport.h"
+#include "HTMLMonthlyCalendarElement.h"
+#include "tjlib-internal.h"
 
-class Project;
-class HTMLMonthlyCalendarElement;
-
-class HTMLMonthlyCalendar : public HTMLReport
+class HTMLMonthlyCalendar : public HTMLSingleReport
 {
 public:
-    HTMLMonthlyCalendar(Project* p, const QString& f, const QString& df, int dl);
-    virtual ~HTMLMonthlyCalendar();
+    HTMLMonthlyCalendar(Project* p, const QString& f, const QString& df, int dl) :
+        HTMLSingleReport(p, f, df, dl)
+    {
+        setTable(new HTMLMonthlyCalendarElement(this, df, dl));
+    }
+
+    virtual ~HTMLMonthlyCalendar()
+    { }
 
     virtual const char* getType() const { return "HTMLMonthlyCalendar"; }
-
-    bool generate();
-    HTMLMonthlyCalendarElement* getTable() { return tab; }
-
-private:
-    HTMLMonthlyCalendar() { }    // don't call this directly
-
-    HTMLMonthlyCalendarElement* tab;
+    virtual QString getTitle() const { return i18n("Monthly Calendar"); }
 } ;
 
 #endif
