@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: HTMLReportElement.cpp 1497 2007-06-13 07:54:55Z cs $
+ * $Id$
  */
 
 #include "HTMLReportElement.h"
@@ -285,13 +285,13 @@ HTMLReportElement::genCell(const QString& text, TableCellInfo* tci,
         {
             puts("padding-left:");
             puts(QString("%1").arg(tci->getLeftPadding()));
-            puts("; ");
+            puts("px; ");
         }
         if (tci->getRightPadding() > 0)
         {
             puts("padding-right:");
             puts(QString("%1").arg(tci->getRightPadding()));
-            puts("; ");
+            puts("px; ");
         }
         if (tci->getBoldText())
             puts("font-weight:bold; ");
@@ -931,6 +931,13 @@ HTMLReportElement::genCellHierarchIndex(TableCellInfo* tci)
             tci->tli->ca1->getHierarchIndex() : QString::null, tci, true);
 }
 
+void
+HTMLReportElement::genCellHierarchLevel(TableCellInfo* tci)
+{
+    genCell(tci->tli->ca2 == 0 ?
+            tci->tli->ca1->getHierarchLevel() : QString::null, tci, true);
+}
+
 void
 HTMLReportElement::genCellId(TableCellInfo* tci)
 {
@@ -1305,6 +1312,69 @@ HTMLReportElement::genCellCompleted(TableCellInfo* tci)
     }
 }
 
+void
+HTMLReportElement::genCellCompletedEffort(TableCellInfo* tci)
+{
+    double val = 0.0;
+
+    if (!tci->tli->resource && tci->tli->task->isLeaf())
+    {
+        // Task line, no resource.
+        val = tci->tli->task->getCompletedLoad(tci->tli->sc);
+    }
+    else if (tci->tli->ca2 && tci->tli->ca2->getType() == CA_Resource &&
+             tci->tli->task && tci->tli->task->isLeaf())
+    {
+        // Task line, nested into a resource
+        const Project* project = report->getProject();
+        time_t now = project->getNow();
+        if (now < project->getStart())
+            now = project->getStart();
+        if (now > project->getEnd())
+            now = project->getEnd();
+        Interval iv = Interval(project->getStart(), now);
+        val = tci->tli->task->getLoad(tci->tli->sc, iv, tci->tli->resource);
+    }
+    else
+    {
+        genCell("", tci, false);
+        return;
+    }
+    generateRightIndented(tci, scaledLoad(val, tci->tcf->realFormat));
+}
+
+void
+HTMLReportElement::genCellRemainingEffort(TableCellInfo* tci)
+{
+    double val = 0.0;
+
+    if (!tci->tli->resource && tci->tli->task->isLeaf())
+    {
+        // Task line, no resource.
+        val = tci->tli->task->getRemainingLoad(tci->tli->sc);
+    }
+    else if (tci->tli->ca2 && tci->tli->ca2->getType() == CA_Resource &&
+             tci->tli->task && tci->tli->task->isLeaf())
+    {
+        // Task line, nested into a resource
+        const Project* project = report->getProject();
+        time_t now = project->getNow();
+        if (now < project->getStart())
+            now = project->getStart();
+        if (now > project->getEnd())
+            now = project->getEnd();
+        Interval iv = Interval(now, project->getEnd());
+        val = tci->tli->task->getLoad(tci->tli->sc, iv, tci->tli->resource);
+    }
+    else
+    {
+        genCell("", tci, false);
+        return;
+    }
+
+    generateRightIndented(tci, scaledLoad(val, tci->tcf->realFormat));
+}
+
 void
 HTMLReportElement::genCellStatus(TableCellInfo* tci)
 {
@@ -1729,6 +1799,12 @@ HTMLReportElement::genCellResponsibilities(TableCellInfo* tci)
     genCell(text, tci, true);
 }
 
+void
+HTMLReportElement::genCellScheduling(TableCellInfo* tci)
+{
+    genCell(tci->tli->task->getSchedulingText(), tci, true);
+}
+
 void
 HTMLReportElement::genCellSchedule(TableCellInfo* tci)
 {
