@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: HTMLReportElement.h 1454 2007-03-23 10:20:38Z cs $
+ * $Id$
  */
 
 #ifndef _HTMLReportElement_h_
@@ -54,6 +54,7 @@ public:
     virtual void genCellHierarchNo(TableCellInfo* tli);
     virtual void genCellIndex(TableCellInfo* tli);
     virtual void genCellHierarchIndex(TableCellInfo* tli);
+    virtual void genCellHierarchLevel(TableCellInfo* tli);
     virtual void genCellId(TableCellInfo* tli);
     virtual void genCellName(TableCellInfo* tli);
     virtual void genCellStart(TableCellInfo* tli);
@@ -84,6 +85,8 @@ public:
     virtual void genCellPriority(TableCellInfo* tli);
     virtual void genCellFlags(TableCellInfo* tli);
     virtual void genCellCompleted(TableCellInfo* tli);
+    virtual void genCellCompletedEffort(TableCellInfo* tli);
+    virtual void genCellRemainingEffort(TableCellInfo* tli);
     virtual void genCellStatus(TableCellInfo* tli);
     virtual void genCellReference(TableCellInfo* tli);
     virtual void genCellScenario(TableCellInfo* tli);
@@ -106,6 +109,7 @@ public:
     virtual void genCellYearlyAccount(TableCellInfo* tli);
     virtual void genCellResponsibilities(TableCellInfo* tli);
     virtual void genCellSchedule(TableCellInfo* tli);
+    virtual void genCellScheduling(TableCellInfo* tli);
     virtual void genCellMinEffort(TableCellInfo* tli);
     virtual void genCellMaxEffort(TableCellInfo* tli);
     virtual void genCellEfficiency(TableCellInfo* tli);
