@@ -8,7 +8,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ICalReport.cpp 1472 2007-04-19 08:47:13Z cs $
+ * $Id$
  */
 
 #include <config.h>
@@ -213,7 +213,7 @@ ICalReport::generate()
 
     // Dump the calendar in ICal format into a text file.
     KCal::ICalFormat format;
-    s << format.toString(&cal).utf8() << endl;
+    s << format.toString(&cal) << endl;
 
     return close();
 }
