@@ -8,7 +8,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Project.h 1493 2007-06-05 13:17:21Z cs $
+ * $Id$
  */
 
 #ifndef _Project_h_
@@ -228,7 +228,22 @@ public:
      * @return true of weeks should start on Monday.
      */
     bool getWeekStartsMonday() const { return weekStartsMonday; }
-
+    /**
+     * Decides if containers which subtasks are all hidden should be
+     * drawn as normal tasks or not.
+     */
+    void setDrawEmptyContainersAsTasks(bool decat)
+    {
+        drawEmptyContainerAsTasks = decat;
+    }
+    /**
+     * @return true if containers which subtasks are all hidden should be
+     * drawn as normal tasks
+     */
+    bool getDrawEmptyContainersAsTasks() const
+    {
+         return drawEmptyContainerAsTasks;
+    }
     /**
      * Set the working hours of the specified weekday.
      * @param day The day of the week. Independently of the weekStartsMonday
@@ -329,7 +344,7 @@ public:
      * the vacation settings. This function sets the value which also affects
      * the monthly working days and the weekly working days.
      */
-    void setYearlyWorkingDays(double d) { yearlyWorkingDays = d; }
+    void setYearlyWorkingDays(double wd) { yearlyWorkingDays = wd; }
     /**
      * Returns the specified number of working days per year.
      */
@@ -361,15 +376,15 @@ public:
      * Returns true if the passed moment falls within any of the vacation
      * intervals.
      */
-    bool isVacation(time_t d) const { return vacationList.isVacation(d); }
+    bool isVacation(time_t vd) const { return vacationList.isVacation(vd); }
 
     /**
      * Returns the name of the first vacation that the given date falls into.
      * If no vacation is found QString::Null is returned.
      */
-    const QString& vacationName(time_t d) const
+    const QString& vacationName(time_t vd) const
     {
-        return vacationList.vacationName(d);
+        return vacationList.vacationName(vd);
     }
 
     /**
@@ -661,7 +676,7 @@ public:
      * Sets the number of decimal digits used for all currency values of the
      * project.
      */
-    void setCurrencyDigits(uint d) { currencyFormat.setFracDigits(d); }
+    void setCurrencyDigits(uint cd) { currencyFormat.setFracDigits(cd); }
 
     /**
      * Sets the default number format for load and other values.
@@ -790,6 +805,9 @@ private:
     /// True if week based calculations use Monday as first day of week.
     bool weekStartsMonday;
 
+    /// True if containers w/o visible subtask should be drawn as normal tasks
+    bool drawEmptyContainerAsTasks;
+
     /// The name of the Project
     QString name;
     /// The revision of the project description.
