@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ReportElement.cpp 1497 2007-06-13 07:54:55Z cs $
+ * $Id$
  */
 
 #include "ReportElement.h"
@@ -94,12 +94,18 @@ ReportElement::ReportElement(Report* r, const QString& df, int dl) :
     tcf->genAccountLine1 = &ReportElement::genCellIndex;
     tcf->hAlign = TableColumnFormat::right;
 
-    tcf = new TableColumnFormat(KW("hierarchindex"), this, i18n("No."));
+    tcf = new TableColumnFormat(KW("hierarchindex"), this, i18n("HierarchIndex"));
     tcf->genTaskLine1 = &ReportElement::genCellHierarchIndex;
     tcf->genResourceLine1 = &ReportElement::genCellHierarchIndex;
     tcf->genAccountLine1 = &ReportElement::genCellHierarchIndex;
     tcf->hAlign = TableColumnFormat::left;
 
+    tcf = new TableColumnFormat(KW("hierarchlevel"), this, i18n("HierarchLevel"));
+    tcf->genTaskLine1 = &ReportElement::genCellHierarchLevel;
+    tcf->genResourceLine1 = &ReportElement::genCellHierarchLevel;
+    tcf->genAccountLine1 = &ReportElement::genCellHierarchLevel;
+    tcf->hAlign = TableColumnFormat::left;
+
     tcf = new TableColumnFormat(KW("id"), this, i18n("Id"));
     tcf->genTaskLine1 = &ReportElement::genCellId;
     tcf->genResourceLine1 = &ReportElement::genCellId;
@@ -257,6 +263,11 @@ ReportElement::ReportElement(Report* r, const QString& df, int dl) :
     tcf->hAlign = TableColumnFormat::left;
     tcf->expandable = true;
 
+    tcf = new TableColumnFormat(KW("scheduling"), this, i18n("Scheduling"));
+    tcf->genTaskLine1 = &ReportElement::genCellScheduling;
+    tcf->hAlign = TableColumnFormat::left;
+    tcf->expandable = true;
+
     tcf = new TableColumnFormat(KW("mineffort"), this, i18n("Min. Effort"));
     tcf->genResourceLine1 = &ReportElement::genCellMinEffort;
     tcf->hAlign = TableColumnFormat::right;
@@ -279,6 +290,20 @@ ReportElement::ReportElement(Report* r, const QString& df, int dl) :
     tcf->hAlign = TableColumnFormat::right;
     tcf->indent = true;
 
+    tcf = new TableColumnFormat(KW("completedeffort"), this,
+                                i18n("Compl. Effort"));
+    tcf->genTaskLine1 = &ReportElement::genCellCompletedEffort;
+    tcf->genTaskLine2 = &ReportElement::genCellCompletedEffort;
+    tcf->hAlign = TableColumnFormat::right;
+    tcf->indent = true;
+
+    tcf = new TableColumnFormat(KW("remainingeffort"), this,
+                                i18n("Rem. Effort"));
+    tcf->genTaskLine1 = &ReportElement::genCellRemainingEffort;
+    tcf->genTaskLine2 = &ReportElement::genCellRemainingEffort;
+    tcf->hAlign = TableColumnFormat::right;
+    tcf->indent = true;
+
     tcf = new TableColumnFormat(KW("status"), this, i18n("Status"));
     tcf->genTaskLine1 = &ReportElement::genCellStatus;
     tcf->genTaskLine2 = &ReportElement::genCellStatus;
@@ -711,7 +736,7 @@ const
          *tli != 0; ++tli)
     {
         bool resourceLoadedInAnyScenario = false;
-        if (r != 0)
+        if (r != 0 && (*tli)->isLeaf())
         {
             QValueList<int>::const_iterator it;
             for (it = scenarios.begin(); it != scenarios.end(); ++it)
@@ -806,7 +831,7 @@ const
          *rli != 0; ++rli)
     {
         bool taskLoadedInAnyScenario = false;
-        if (t != 0)
+        if (t != 0 && t->isLeaf())
         {
             QValueList<int>::const_iterator it;
             for (it = scenarios.begin(); it != scenarios.end(); ++it)
@@ -1024,6 +1049,10 @@ ReportElement::setMacros(TableLineInfo* tli)
                           tli->ca1 ? tli->ca1->getHierarchIndex() :
                           QString::null,
                           defFileName, defFileLine));
+    mt.addMacro(new Macro(KW("hierarchlevel"),
+                          tli->ca1 ? tli->ca1->getHierarchLevel() :
+                          QString::null,
+                          defFileName, defFileLine));
     mt.addMacro(new Macro(KW("name"),
                           tli->ca1 ? tli->ca1->getName() : QString::null,
                           defFileName, defFileLine));
