@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ReportElement.h 1472 2007-04-19 08:47:13Z cs $
+ * $Id$
  */
 #ifndef _ReportElement_h_
 #define _ReportElement_h_
@@ -193,6 +193,7 @@ public:
     virtual void genCellHierarchNo(TableCellInfo*) = 0;
     virtual void genCellIndex(TableCellInfo*) = 0;
     virtual void genCellHierarchIndex(TableCellInfo*) = 0;
+    virtual void genCellHierarchLevel(TableCellInfo*) = 0;
     virtual void genCellId(TableCellInfo*) = 0;
     virtual void genCellName(TableCellInfo*) = 0;
     virtual void genCellStart(TableCellInfo*) = 0;
@@ -223,6 +224,8 @@ public:
     virtual void genCellPriority(TableCellInfo*) = 0;
     virtual void genCellFlags(TableCellInfo*) = 0;
     virtual void genCellCompleted(TableCellInfo*) = 0;
+    virtual void genCellCompletedEffort(TableCellInfo*) = 0;
+    virtual void genCellRemainingEffort(TableCellInfo*) = 0;
     virtual void genCellStatus(TableCellInfo*) = 0;
     virtual void genCellReference(TableCellInfo*) = 0;
     virtual void genCellScenario(TableCellInfo*) = 0;
@@ -245,6 +248,7 @@ public:
     virtual void genCellYearlyAccount(TableCellInfo*) = 0;
     virtual void genCellResponsibilities(TableCellInfo*) = 0;
     virtual void genCellSchedule(TableCellInfo*) = 0;
+    virtual void genCellScheduling(TableCellInfo*) = 0;
     virtual void genCellMinEffort(TableCellInfo*) = 0;
     virtual void genCellMaxEffort(TableCellInfo*) = 0;
     virtual void genCellEfficiency(TableCellInfo*) = 0;
