@@ -13,11 +13,7 @@
 #ifndef _ReportElementBase_h_
 #define _ReportElementBase_h_
 
-#include <qstring.h>
-#include <qvaluelist.h>
-
 #include "Report.h"
-#include "RealFormat.h"
 
 /**
  * @short A class that forms the base for elements of a report.
@@ -38,8 +34,6 @@ public:
     const RealFormat& getNumberFormat() const { return numberFormat; }
 
 protected:
-    ReportElementBase() { }
-
     QString scaledValue(double t, const RealFormat& realFormat,
                         bool showUnit, bool longUnit,
                         const QValueList<double>& factors) const;
