@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Resource.cpp 1497 2007-06-13 07:54:55Z cs $
+ * $Id$
  */
 
 #include "Resource.h"
@@ -643,7 +643,7 @@ Resource::getCurrentLoadSub(uint startIdx, uint endIdx, const Task* task) const
         SbBooking* b = scoreboard[i];
         if (b < (SbBooking*) 4)
             continue;
-        if (task == 0 || task == b->getTask())
+        if (!task || task == b->getTask() || b->getTask()->isDescendantOf(task))
             bookings++;
     }
 
@@ -678,7 +678,7 @@ Resource::getCurrentDaySlots(time_t date, const Task* t)
         if (b < (SbBooking*) 4)
             continue;
 
-        if (!t || b->getTask() == t)
+        if (!t || b->getTask() == t || b->getTask()->isDescendantOf(t))
             bookedSlots++;
     }
 
@@ -713,7 +713,7 @@ Resource::getCurrentWeekSlots(time_t date, const Task* t)
         if (b < (SbBooking*) 4)
             continue;
 
-        if (!t || b->getTask() == t)
+        if (!t || b->getTask() == t || b->getTask()->isDescendantOf(t))
             bookedSlots++;
     }
 
@@ -748,7 +748,7 @@ Resource::getCurrentMonthSlots(time_t date, const Task* t)
         if (b < (SbBooking*) 4)
             continue;
 
-        if (!t || b->getTask() == t)
+        if (!t || b->getTask() == t || b->getTask()->isDescendantOf(t))
             bookedSlots++;
     }
 
@@ -838,7 +838,7 @@ Resource::getAllocatedSlots(int sc, uint startIdx, uint endIdx,
             bool isAllocated = false;
             for (TaskListIterator tli(scenarios[sc].allocatedTasks); *tli;
                  ++tli)
-                if (task == *tli)
+                if (task == *tli || (*tli)->isDescendantOf(task))
                 {
                     isAllocated = true;
                     break;
@@ -858,7 +858,8 @@ Resource::getAllocatedSlots(int sc, uint startIdx, uint endIdx,
         if (b < (SbBooking*) 4)
             continue;
         if ((task == 0 ||
-             (task != 0 && task == b->getTask())) &&
+             (task != 0 && (task == b->getTask() ||
+                            b->getTask()->isDescendantOf(task)))) &&
             (acctType == AllAccounts ||
              (b->getTask()->getAccount() &&
               b->getTask()->getAccount()->getAcctType() == acctType)))
@@ -1030,7 +1031,7 @@ Resource::isAllocatedSub(int sc, uint startIdx, uint endIdx, const Task* task)
         SbBooking* b = scoreboards[sc][i];
         if (b < (SbBooking*) 4)
             continue;
-        if (task == 0 || b->getTask() == task)
+        if (!task || b->getTask() == task || b->getTask()->isDescendantOf(task))
             return true;
     }
     return false;
@@ -1055,7 +1056,8 @@ Resource::getPIDs(int sc, const Interval& period, const Task* task,
         SbBooking* b = scoreboards[sc][i];
         if (b < (SbBooking*) 4)
             continue;
-        if ((task == 0 || task == b->getTask()) &&
+        if ((!task || task == b->getTask() ||
+             b->getTask()->isDescendantOf(task)) &&
             pids.findIndex(b->getTask()->getProjectId()) == -1)
         {
             pids.append(b->getTask()->getProjectId());
