@@ -8,7 +8,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Task.h 1497 2007-06-13 07:54:55Z cs $
+ * $Id$
  */
 
 #ifndef _Task_h_
@@ -240,6 +240,8 @@ public:
     TaskStatus getStatus(int sc) const { return scenarios[sc].status; }
     QString getStatusText(int sc) const;
 
+    QString getSchedulingText() const;
+
     bool isCompleted(int sc, time_t date) const;
     void calcCompletionDegree(int sc);
     void calcContainerCompletionDegree(int sc, time_t now);
@@ -249,6 +251,8 @@ public:
     {
         return scenarios[sc].status;
     }
+    double getCompletedLoad(int sc) const;
+    double getRemainingLoad(int sc) const;
 
     double getLoad(int sc, const Interval& period, const Resource* resource = 0)
         const;
@@ -293,7 +297,7 @@ public:
     double getCriticalness(int sc) const { return scenarios[sc].criticalness; }
     void checkAndMarkCriticalPath(int sc, double minSlack, time_t maxEnd);
 
-    void computePathCriticalness(int sc);
+    double computePathCriticalness(int sc);
     double getPathCriticalness(int sc) const
     {
         return scenarios[sc].pathCriticalness;
@@ -312,6 +316,12 @@ public:
         return scenarios[sc].criticalLinks.containsRef(t);
     }
 
+    /**
+     * @retval true if itself or one of its subtasks (recursively) is on the critical path
+     * @retval false otherwise.
+     */
+    bool isOrHasDescendantOnCriticalPath(int sc) const;
+
     bool isContainer() const { return !sub->isEmpty(); }
 
     bool xRef(QDict<Task>& hash);
@@ -340,7 +350,7 @@ public:
     void setRunaway();
     bool isRunaway() const;
 
-    bool isSubTask(Task* t) const;
+    bool isSubTask(const Task* t) const;
 
     bool isSchedulingDone() const { return schedulingDone; }
 
@@ -387,9 +397,6 @@ private:
     bool hasStartDependency() const;
     bool hasEndDependency() const;
 
-    double computeBackwardCriticalness(int sc);
-    double computeForwardCriticalness(int sc);
-
     bool analyzePath(int sc, double minSlack, time_t pathStart, long busyTime,
                      long worstMinSlackTime, long& checked, long& found);
     void collectTransientFollowers(TaskList& list);
