@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Utility.cpp 1498 2007-06-20 08:21:49Z cs $
+ * $Id$
  */
 
 #include "Utility.h"
@@ -17,6 +17,7 @@
 #include <cstring>
 
 #include <string>
+#include <stdlib.h>
 
 #include <qdict.h>
 
@@ -877,6 +878,25 @@ date2time(const QString& date)
     return localTime;
 }
 
+QDate
+time2qdate(time_t t)
+{
+    return QDate(year(t), monthOfYear(t), dayOfMonth(t));
+}
+
+time_t
+qdate2time(const QDate& d)
+{
+#if defined(__CYGWIN__) || (defined(__SVR4) && defined(__sun))
+    struct tm t = { 0, 0, 0, d.day(), d.month() - 1, d.year() - 1900,
+                    0, 0, -1 };
+#else
+    struct tm t = { 0, 0, 0, d.day(), d.month() - 1, d.year() - 1900,
+                    0, 0, -1, 0, 0 };
+#endif
+    return mktime(&t);
+}
+
 #if defined(__SVR4) && defined(__sun)
 /*
  * Note: a proper implementation of a "setenv" function for Solaris
@@ -891,7 +911,7 @@ int setenv(const char* var, const char* val, int ignore)
    int valLen = strlen(val);
    char *buffer = NULL;
 
-   if ((buffer = static_cast<char*> malloc(varLen + valLen + 2)) == NULL)
+   if ((buffer = static_cast<char*>(malloc(varLen + valLen + 2))) == NULL)
       return -1;
 
    sprintf (buffer, "%s=%s", var, val);
